Index: tests/language_2/unresolved_in_factory_test.dart |
diff --git a/tests/language/unresolved_in_factory_negative_test.dart b/tests/language_2/unresolved_in_factory_test.dart |
similarity index 70% |
rename from tests/language/unresolved_in_factory_negative_test.dart |
rename to tests/language_2/unresolved_in_factory_test.dart |
index 8166ac8f510bf5356ed452ec5ea23d2879116826..a9aa72abc720afdd89968eb51f9f6b6d46167c62 100644 |
--- a/tests/language/unresolved_in_factory_negative_test.dart |
+++ b/tests/language_2/unresolved_in_factory_test.dart |
@@ -2,12 +2,11 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
// Test that an unresolved method call in a factory is a resolution |
// error. |
class A { |
factory A() { |
- foo(); |
+ foo(); /*@compile-error=unspecified*/ |
} |
} |
@@ -2,12 +2,11 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE file. |
-// Test that an unresolved method call in a factory is a resolution |
-// error. |
+// Test that an unresolved method call in a factory is a compile error. |
class A { |
factory A() { |